# `BioClients.util`

Miscellaneous utilities for web service clients.

##  `pandas`

Processing CSV/TSV files.

##  `rest`

Convenience functions for REST APIs.

##  `sparql`

For Sparql endpoints.

### Dependencies

* Python packages: `SPARQLWrapper`

##  `xml`

Processing XML with `xml.etree.ElementTree`.

##  `hdf`

[HDF5](https://www.hdfgroup.org/) (hierarchical data format)
file processing, using [h5py, HDF5 for Python](https://docs.h5py.org/).
